@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Plugin Updates
-    Version ........ 0.6
+    Version ........ 0.7
     Purpose ........ Check your currently installed plugins for updates
 
 *******************************************************************************/
@@ -14,9 +14,11 @@
       define('SM_PATH','../');
 
    function squirrelmail_plugin_init_pupdate() {
-      global $squirrelmail_plugin_hooks;
-      $squirrelmail_plugin_hooks['menuline']['pupdate'] = 'pupdate';
-      $squirrelmail_plugin_hooks['optpage_register_block']['pupdate'] = 'pupdate_optpage';
+      global $squirrelmail_plugin_hooks, $plugins;
+      if (in_array('admin_options',$plugins))
+         $squirrelmail_plugin_hooks['admin_optpage_register_block']['pupdate'] = 'pupdate_optpage';
+      else
+         $squirrelmail_plugin_hooks['optpage_register_block']['pupdate'] = 'pupdate_optpage';
    }
 
    function pupdate_optpage() {
@@ -24,7 +26,7 @@
    }
 
    function pupdate_version() {
-      return 0.6;
+      return "0.7";
    }
 
 ?>
\ No newline at end of file
